@@ -24,15 +24,13 @@ namespace GnomeSubtitles {
 
 public class VideoFileOpenErrorDialog : FileOpenErrorDialog {
 
-	public VideoFileOpenErrorDialog (string filename, Exception exception) : base(filename, exception) {
+	public VideoFileOpenErrorDialog (Uri uri, Exception exception) : base(uri, exception) {
 	}
 
 	/* Overriden members */
 	
 	protected override string SecondaryTextFromException (Exception exception) {
-		if (exception is PlayerNotFoundException)
-			return Catalog.GetString("Unable to start the video player. Please check that MPlayer is installed.");
-		else if (exception is PlayerCouldNotOpenVideoException)
+		if (exception is PlayerCouldNotOpenVideoException)
 			return Catalog.GetString("Please check that the video file is supported.");
 		else
 			return String.Empty;
